@@ -36,7 +36,7 @@ switch ($step) {
 
 <div style="width: 48%; float: left;">
 <h3><?php _e('Or choose from your local disk:'); ?></h3>
-<input name="userfile" type="file" size="30" />
+<input id="userfile" name="userfile" type="file" size="30" />
 </div>
 
 
@@ -77,13 +77,13 @@ foreach ($categories as $category) {
                 }
 
                 $opml_url = $_POST['opml_url'];
-                if (isset($opml_url) && $opml_url != '') {
+                if (isset($opml_url) && $opml_url != '' && $opml_url != 'http://') {
 					$blogrolling = true;
                 }
                 else // try to get the upload file.
 				{
 					$overrides = array('test_form' => false, 'test_type' => false);
-					$file = wp_handle_upload($_FILES['import'], $overrides);
+					$file = wp_handle_upload($_FILES['userfile'], $overrides);
 
 					if ( isset($file['error']) )
 						die($file['error']);
@@ -126,6 +126,7 @@ foreach ($categories as $category) {
                 break;
             } // end case 1
 } // end switch
+
+include('admin-footer.php');
+
 ?>
-</body>
-</html>
